==> huaweicloudsdkief-3.0.80-py2.py3-none-any.whl: huaweicloudsdkief/v1/model/list_secrets_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSecretsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'secrets': 'list[SecretDetailResp]',
        'count': 'int'
    }

    attribute_map = {
        'secrets': 'secrets',
        'count': 'count'
    }

    def __init__(self, secrets=None, count=None):
        """ListSecretsResponse - a model defined in huaweicloud sdk"""
        
        super(ListSecretsResponse, self).__init__()

        self._secrets = None
        self._count = None
        self.discriminator = None

        if secrets is not None:
            self.secrets = secrets
        if count is not None:
            self.count = count

    @property
    def secrets(self):
        """Gets the secrets of this ListSecretsResponse.

        密钥

        :return: The secrets of this ListSecretsResponse.
        :rtype: list[SecretDetailResp]
        """
        return self._secrets

    @secrets.setter
    def secrets(self, secrets):
        """Sets the secrets of this ListSecretsResponse.

        密钥

        :param secrets: The secrets of this ListSecretsResponse.
        :type: list[SecretDetailResp]
        """
        self._secrets = secrets

    @property
    def count(self):
        """Gets the count of this ListSecretsResponse.

        满足条件的个数

        :return: The count of this ListSecretsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListSecretsResponse.

        满足条件的个数

        :param count: The count of this ListSecretsResponse.
        :type: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSecretsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkief-3.0.102-py2.py3-none-any.whl: huaweicloudsdkief/v1/model/list_secrets_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSecretsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'secrets': 'list[SecretDetailResp]',
        'count': 'int'
    }

    attribute_map = {
        'secrets': 'secrets',
        'count': 'count'
    }

    def __init__(self, secrets=None, count=None):
        """ListSecretsResponse

        The model defined in huaweicloud sdk

        :param secrets: 密钥
        :type secrets: list[:class:`huaweicloudsdkief.v1.SecretDetailResp`]
        :param count: 满足条件的个数
        :type count: int
        """
        
        super(ListSecretsResponse, self).__init__()

        self._secrets = None
        self._count = None
        self.discriminator = None

        if secrets is not None:
            self.secrets = secrets
        if count is not None:
            self.count = count

    @property
    def secrets(self):
        """Gets the secrets of this ListSecretsResponse.

        密钥

        :return: The secrets of this ListSecretsResponse.
        :rtype: list[:class:`huaweicloudsdkief.v1.SecretDetailResp`]
        """
        return self._secrets

    @secrets.setter
    def secrets(self, secrets):
        """Sets the secrets of this ListSecretsResponse.

        密钥

        :param secrets: The secrets of this ListSecretsResponse.
        :type secrets: list[:class:`huaweicloudsdkief.v1.SecretDetailResp`]
        """
        self._secrets = secrets

    @property
    def count(self):
        """Gets the count of this ListSecretsResponse.

        满足条件的个数

        :return: The count of this ListSecretsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListSecretsResponse.

        满足条件的个数

        :param count: The count of this ListSecretsResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSecretsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
